@@ -733,10 +733,10 @@ synthetic_instruct = MultipleChoice('prompt', choices=['chosen', 'rejected'],
 scruples = Classification("text",labels="binarized_label",dataset_name="metaeval/scruples")
 
 wouldyourather = MultipleChoice(constant(''), choices=['option_a','option_b'],
-    labels= lambda x: int(x['votes_b']<['votes_a']),
+    labels= lambda x: int(x['votes_a']<['votes_b']),
     dataset_name="metaeval/wouldyourather")
 
 attempto_nli = Classification("premise","hypothesis","race_label",dataset_name="sileod/attempto-nli")
 
 defeasible_nli = Classification(cat(["Premise","Hypothesis"]),"Update",labels="UpdateType",
-    dataset_name="metaeval/defeasible-nli",config_name=['atomic', 'snli', 'social'])
\ No newline at end of file
+    dataset_name="metaeval/defeasible-nli",config_name=['atomic', 'snli', 'social'])
